#
# spec file for package containers-systemd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define containers bind cups dhcp-server dovecot fetchmail haproxy mariadb minidlna nfs-server nginx openldap postfix roundcube samba spamassassin squid wsdd
%define container_services container-bind.service container-cups.service container-dhcp-server.service container-dhcp6-server.service container-dovecot.service container-fetchmail.service container-haproxy.service container-mariadb.service container-minidlna.service container-nfs-server.service container-nginx.service container-openldap.service container-postfix.service container-roundcube.service container-samba.service container-spamassassin.service container-squid.service container-wsdd.service container-image-prune.service container-image-prune.timer container-certbot-renew.service container-certbot-renew.timer

%if %{undefined service_del_postun_without_restart}
%define service_del_postun_without_restart() \
DISABLE_RESTART_ON_UPDATE=1 \
%service_del_postun %{?*}
%endif

Name:           containers-systemd
Version:        0.0+git20231208.299201e
Release:        1.2
Summary:        Systemd service files and config files for openSUSE container
License:        MIT
URL:            https://github.com/openSUSE/containers-systemd
Source:         containers-systemd-%{version}.tar.xz
Source1:        containers-systemd.rpmlintrc
BuildArch:      noarch

%description
This package contains the configuration files and systemd units
to run the openSUSE containers via podman managed by systemd.
Currently supported are bind, cups, dhcp-server, dovecot, fetchmail, haproxy,
mariadb, minidlna, nginx, openldap, postfix, roundcube, samba,
spamassassin, squid and wsdd. Additional, there is a timer to cleanup
dangling container images.

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_distconfdir}/default
for i in %{containers}; do
    mkdir -p %{buildroot}/srv/$i
    install -m 644 container-$i.default %{buildroot}%{_distconfdir}/default/container-$i
    install -m 644 container-$i.service %{buildroot}%{_unitdir}/
    # create symlink for rccontainer-*
    ln -s /sbin/service %{buildroot}%{_sbindir}/rccontainer-$i
done
install -m 644 container-certbot.default %{buildroot}%{_distconfdir}/default/container-certbot
install -m 644 container-certbot-renew.service %{buildroot}%{_unitdir}/
install -m 644 container-certbot-renew.timer %{buildroot}%{_unitdir}/
install -m 644 container-dhcp6-server.service %{buildroot}%{_unitdir}/
ln -s /sbin/service %{buildroot}%{_sbindir}/rccontainer-dhcp6-server
install -m 644 container-image-prune.service %{buildroot}%{_unitdir}/
install -m 644 container-image-prune.timer %{buildroot}%{_unitdir}/
mkdir -p %{buildroot}%{_sysconfdir}/mariadb-secrets
for i in MYSQL_ROOT_PASSWORD MYSQL_ROOT_HOST MYSQL_DATABASE MYSQL_USER MYSQL_PASSWORD; do
  touch %{buildroot}%{_sysconfdir}/mariadb-secrets/$i
done
mkdir -p %{buildroot}%{_sysconfdir}/openldap-secrets
for i in LDAP_ADMIN_PASSWORD LDAP_CONFIG_PASSWORD; do
  touch %{buildroot}%{_sysconfdir}/openldap-secrets/$i
done
mkdir -p %{buildroot}%{_sysconfdir}/postfix-secrets
for i in SMTP_PASSWORD LDAP_BIND_PASSWORD; do
  touch %{buildroot}%{_sysconfdir}/postfix-secrets/$i
done

%pre
%service_add_pre %{container_services}

%post
%service_add_post %{container_services}

%preun
%service_del_preun %{container_services}

%postun
# Avoid useless container restarts on update of this package
%service_del_postun_without_restart %{container_services}

%files
%license LICENSE
%doc README.md
%{_unitdir}/container-bind.service
%{_distconfdir}/default/container-bind
%{_sbindir}/rccontainer-bind
%ghost %dir /srv/bind
%{_unitdir}/container-cups.service
%{_distconfdir}/default/container-cups
%{_sbindir}/rccontainer-cups
%ghost %dir /srv/cups
%{_unitdir}/container-certbot-renew.service
%{_unitdir}/container-certbot-renew.timer
%{_distconfdir}/default/container-certbot
%{_unitdir}/container-dhcp-server.service
%{_unitdir}/container-dhcp6-server.service
%{_distconfdir}/default/container-dhcp-server
%{_sbindir}/rccontainer-dhcp-server
%{_sbindir}/rccontainer-dhcp6-server
%ghost %dir /srv/dhcp-server
%{_unitdir}/container-dovecot.service
%{_distconfdir}/default/container-dovecot
%{_sbindir}/rccontainer-dovecot
%ghost %dir /srv/dovecot
%{_unitdir}/container-fetchmail.service
%{_distconfdir}/default/container-fetchmail
%{_sbindir}/rccontainer-fetchmail
%{_unitdir}/container-haproxy.service
%{_distconfdir}/default/container-haproxy
%{_sbindir}/rccontainer-haproxy
%ghost %dir /srv/haproxy
%{_unitdir}/container-mariadb.service
%{_distconfdir}/default/container-mariadb
%{_sbindir}/rccontainer-mariadb
%ghost %dir /srv/mariadb
%dir %attr(0700,root,root) %{_sysconfdir}/mariadb-secrets
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_ROOT_PASSWORD
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_ROOT_HOST
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_DATABASE
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_USER
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/mariadb-secrets/MYSQL_PASSWORD
%{_unitdir}/container-minidlna.service
%{_distconfdir}/default/container-minidlna
%{_sbindir}/rccontainer-minidlna
%{_unitdir}/container-nfs-server.service
%{_distconfdir}/default/container-nfs-server
%{_sbindir}/rccontainer-nfs-server
%{_unitdir}/container-nginx.service
%{_distconfdir}/default/container-nginx
%{_sbindir}/rccontainer-nginx
%ghost %dir /srv/nginx
%{_unitdir}/container-openldap.service
%{_distconfdir}/default/container-openldap
%{_sbindir}/rccontainer-openldap
%ghost %dir /srv/openldap
%dir %attr(0700,root,root) %{_sysconfdir}/openldap-secrets
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/openldap-secrets/LDAP_ADMIN_PASSWORD
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/openldap-secrets/LDAP_CONFIG_PASSWORD
%{_unitdir}/container-postfix.service
%{_distconfdir}/default/container-postfix
%{_sbindir}/rccontainer-postfix
%ghost %dir /srv/postfix
%dir %attr(0700,root,root) %{_sysconfdir}/postfix-secrets
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/postfix-secrets/SMTP_PASSWORD
%config(noreplace) %attr(0600,root,root) %{_sysconfdir}/postfix-secrets/LDAP_BIND_PASSWORD
%{_unitdir}/container-roundcube.service
%{_distconfdir}/default/container-roundcube
%{_sbindir}/rccontainer-roundcube
%{_unitdir}/container-samba.service
%{_distconfdir}/default/container-samba
%{_sbindir}/rccontainer-samba
%{_unitdir}/container-spamassassin.service
%{_distconfdir}/default/container-spamassassin
%{_sbindir}/rccontainer-spamassassin
%{_unitdir}/container-squid.service
%{_distconfdir}/default/container-squid
%{_sbindir}/rccontainer-squid
%ghost %dir /srv/squid
%{_unitdir}/container-wsdd.service
%{_distconfdir}/default/container-wsdd
%{_sbindir}/rccontainer-wsdd
%{_unitdir}/container-image-prune.service
%{_unitdir}/container-image-prune.timer

%changelog
* Fri Dec  8 2023 kukuk@suse.com
- Update to version 0.0+git20231208.299201e:
  * certbot needs a tty
  * wsdd: don't run binary to set HOSTNAME
* Fri Mar 24 2023 kukuk@suse.com
- Update to version 0.0+git20230324.9cd3b7a:
  * container-certbot-renew.service is a oneshot service
* Thu Aug 11 2022 kukuk@suse.com
- Update to version 0.0+git20220811.226e80e:
  * Add service for cups container
  * Make sure dhcp container has NET_RAW capabilities
* Wed Jul 13 2022 kukuk@suse.com
- Update to version 0.0+git20220713.967c6f4:
  * Add submission/smtps support for postfix
* Sun Jul 10 2022 kukuk@suse.com
- Update to version 0.0+git20220710.f290756:
  * container-openldap: fix syntax error in ExecStart
* Wed Jul  6 2022 kukuk@suse.com
- Update to version 0.0+git20220706.2c928fe:
  * Fix partly missing SELinux support (#5), call podman directly
* Tue Jun 28 2022 kukuk@suse.com
- Update to version 0.0+git20220628.ee9e63c:
  * Add files to renew certificates with certbot
* Mon Jan 31 2022 kukuk@suse.com
- Update to version 0.0+git20220131.79f09c7:
  * Adjust timing for start limits in case of errors
  * Fix typo
* Tue Nov 30 2021 kukuk@suse.com
- Update to version 0.0+git20211130.31bd054:
  * Use Type=notify instead of forking (following podman upstream)
* Mon Nov 29 2021 kukuk@suse.com
- Update to version 0.0+git20211129.1b144ae:
  * Add roundcube files
* Fri May  7 2021 kukuk@suse.com
- Update to version 0.0+git20210507.9afe2a6:
  * Add files for samba
* Wed Apr  7 2021 kukuk@suse.com
- Update to version 0.0+git20210407.9384691:
  * Add service for wsdd
* Thu Mar 18 2021 kukuk@suse.com
- Update to version 0.0+git20210318.fea98a6:
  * Add lost podman pull back
  * nginx: fix syntax error
* Mon Feb 22 2021 kukuk@suse.com
- Update to version 0.0+git20210222.f3de7fa:
  * Rewrite based on podman changes
  * Correct TimeoutStopSec to 70
  * Replace KillMode=none with TimeoutStopSec
* Fri Feb  5 2021 kukuk@suse.com
- Update to version 0.0+git20210205.a4b07b6:
  * Add container-nfs-service files
* Mon Jan 18 2021 kukuk@suse.com
- Update to version 0.0+git20210118.1366ecb:
  * postfix: provide SPAMASSASSIN_HOST environment variable
* Thu Jan  7 2021 kukuk@suse.com
- Update to version 0.0+git20210107.f55f4b3:
  * postfix: provide SMTP_TLS_SECURITY_LEVEL variable
* Thu Jan  7 2021 kukuk@suse.com
- Update to version 0.0+git20210107.5e7d60c:
  * spamassassin: add volume for configuration files
* Tue Jan  5 2021 kukuk@suse.com
- Update to version 0.0+git20210105.c149375:
  * postfix: Add SMTP_PORT and NULLCLIENT
* Sun Dec 20 2020 kukuk@suse.com
- Update to version 0.0+git20201220.ed8a6b2:
  * Add default for FETCHMAILRC
* Sun Dec 20 2020 kukuk@suse.com
- Update to version 0.0+git20201220.0fae7ba:
  * Add service for fetchmail container
* Sun Dec 20 2020 kukuk@suse.com
- Update to version 0.0+git20201220.69a11d7:
  * Document spamassassin support
  * Add support for a spamassassin container
* Thu Dec 17 2020 Thorsten Kukuk <kukuk@suse.com>
- LDAP_MAIL_READER_PASSWORD was renamed to LDAP_BIND_PASSWORD
- Update to version 0.0+git20201217.a84253d:
  * Allow to overwrite TLS key location
* Tue Dec  8 2020 kukuk@suse.com
- Update to version 0.0+git20201208.1b4413e:
  * Add support for dovecot
  * Fix description
  * Add support for minidlna container
  * Add LMTP variable
* Fri Nov 13 2020 kukuk@suse.com
- Update to version 0.0+git20201113.5e435e8:
  * Make more options configureable
  * Make list of ports to export configureable
  * Only restart containers when the process fails abnormally
  * Add LDAP_BIND_DN, make password files configureable
* Tue Oct 27 2020 kukuk@suse.com
- Update to version 0.0+git20201027.f1d33d8:
  * Add a way to provide pki directory to postfix
* Mon Oct 26 2020 kukuk@suse.com
- Update to version 0.0+git20201026.4046317:
  * Start some services only after firewall is running
* Fri Oct 23 2020 kukuk@suse.com
- Update to version 0.0+git20201023.1bb4d20:
  * Point to documentation in wiki
  * Unify names of spool directories
  * Fix name of container
  * Fix typo
* Fri Sep 18 2020 rbrown@suse.com
- Update to version 0.0+git20200918.c14836a:
  * All services should 'Want=' targets not just 'After='
* Tue Sep  1 2020 kukuk@suse.com
- Update to version 0.0+git20200901.c31b0cc:
  * Add LDAP_TLS_VERIFY_CLIENT, use "organization"
* Fri Aug 28 2020 kukuk@suse.com
- Update to version 0.0+git20200828.7cc6e97:
  * Add support for postfix container
* Tue Aug 25 2020 kukuk@suse.com
- Update to version 0.0+git20200825.e6c35ce:
  * Allow extra args for podman for the ldap container
* Mon Aug 24 2020 kukuk@suse.com
- Update to version 0.0+git20200824.8ed78c3:
  * New files to support OpenLDAP
  * Adjust documentation
* Tue Jun  2 2020 kukuk@suse.com
- Update to version 0.0+git20200602.25da9c0:
  * Fix creation of nginx directories
* Tue Jun  2 2020 kukuk@suse.com
- Update to version 0.0+git20200602.570333a:
  * Move from sysconfig to /etc/default to seperate defaults from user made
    changes (containers-systemd#1)
  * Use conmon-pidfile for better systemd integration
    (container-registry-systemd#2)
* Fri Apr 24 2020 Ludwig Nussel <lnussel@suse.de>
- use SLE15 compatible %%service_del_postun
* Mon Mar 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Package service file for squid conainer
* Tue Mar 24 2020 kukuk@suse.com
- Update to version 0.0+git20200324.5f4ae65:
  * Add timer to prune unnamed images
* Wed Feb 19 2020 kukuk@suse.com
- Update to version 0.0+git20200219.a6acfd1:
  * Adjust for new nginx container image
  * Fix comment
* Mon Feb 17 2020 kukuk@suse.com
- Update to version 0.0+git20200217.580c00f:
  * Add squid
* Wed Feb 12 2020 kukuk@suse.com
- Update to version 0.0+git20200212.47b21c6:
  * Add haproxy
* Thu Jan 30 2020 kukuk@suse.com
- Update to version 0.0+git20200124.e3c2408:
  * Fix network parameter for dhcp servers
* Wed Jan 22 2020 kukuk@suse.com
- Update to version 0.0+git20200122.8276c03:
  * Add support for nginx container
* Fri Jan 17 2020 Thorsten Kukuk <kukuk@suse.com>
- Use new macro to prevent restart on update
* Thu Jan 16 2020 kukuk@suse.com
- Update to version 0.0+git20200116.87baa97:
  * Start container only after network, don't abort if pull fails
* Wed Oct 30 2019 kukuk@suse.com
- Add mariadb files
- Update to version 0.0+git20191030.b2f919f:
  * Fix typo, mention which variable adjusts secrets path for mariadb
  * Add environment variables and files to initialize mariadb at first startup
  * Enhance documentation
  * Add first mariadb service and sysconfig file
  * Mention dhcp6-server
* Tue Oct 29 2019 kukuk@suse.com
- Update to version 0.0+git20191029.39ca697:
  * Provide dhcpd4 and dhcpd6 service files
* Mon Oct 28 2019 kukuk@suse.com
- Update to version 0.0+git20191028.2cbfdca:
  * Add sysconfig and service file for dhcp-server container image
* Sat Oct 26 2019 kukuk@suse.com
- Update to version 0.0+git20191026.e3a4918:
  * Add service and sysconfig file for bind container
